Lorem ipsum
-----------

Lorem ipsum dolor sit amet
.. $if branch in '12.0'
odoo 12.0
.. $elif branch in '10.0'
odoo 10.0
.. $elif branch in '10.0'
odoo 8.0
.. $else
consectetur adipiscing elit
.. $fi
